Enum TIP20Event
pub enum TIP20Event {
Show 14 variants
Transfer(Transfer),
Approval(Approval),
Mint(Mint),
Burn(Burn),
BurnBlocked(BurnBlocked),
TransferWithMemo(TransferWithMemo),
TransferPolicyUpdate(TransferPolicyUpdate),
SupplyCapUpdate(SupplyCapUpdate),
PauseStateUpdate(PauseStateUpdate),
NextQuoteTokenSet(NextQuoteTokenSet),
QuoteTokenUpdate(QuoteTokenUpdate),
RewardDistributed(RewardDistributed),
RewardRecipientSet(RewardRecipientSet),
LogoURIUpdated(LogoURIUpdated),
}Expand description
Container for all the ITIP20 events.
Variants
Transfer(Transfer)
Approval(Approval)
Mint(Mint)
Burn(Burn)
BurnBlocked(BurnBlocked)
TransferWithMemo(TransferWithMemo)
TransferPolicyUpdate(TransferPolicyUpdate)
SupplyCapUpdate(SupplyCapUpdate)
PauseStateUpdate(PauseStateUpdate)
NextQuoteTokenSet(NextQuoteTokenSet)
QuoteTokenUpdate(QuoteTokenUpdate)
RewardDistributed(RewardDistributed)
RewardRecipientSet(RewardRecipientSet)
LogoURIUpdated(LogoURIUpdated)
Implementations
impl ITIP20Events
impl ITIP20Events
pub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
pub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
pub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>
pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>
Returns the signature for the given selector, if known.
pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>
pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>
Returns the enum variant name for the given selector, if known.
impl ITIP20Events
impl ITIP20Events
pub fn transfer(
from: Address,
to: Address,
amount: Uint<256, 4>,
) -> ITIP20Events
pub fn transfer( from: Address, to: Address, amount: Uint<256, 4>, ) -> ITIP20Events
Creates a Transfer event.
event Transfer(address,address,uint256)pub fn approval(
owner: Address,
spender: Address,
amount: Uint<256, 4>,
) -> ITIP20Events
pub fn approval( owner: Address, spender: Address, amount: Uint<256, 4>, ) -> ITIP20Events
Creates a Approval event.
event Approval(address,address,uint256)pub fn mint(to: Address, amount: Uint<256, 4>) -> ITIP20Events
pub fn mint(to: Address, amount: Uint<256, 4>) -> ITIP20Events
Creates a Mint event.
event Mint(address,uint256)pub fn burn(from: Address, amount: Uint<256, 4>) -> ITIP20Events
pub fn burn(from: Address, amount: Uint<256, 4>) -> ITIP20Events
Creates a Burn event.
event Burn(address,uint256)pub fn burn_blocked(from: Address, amount: Uint<256, 4>) -> ITIP20Events
pub fn burn_blocked(from: Address, amount: Uint<256, 4>) -> ITIP20Events
Creates a BurnBlocked event.
event BurnBlocked(address,uint256)pub fn transfer_with_memo(
from: Address,
to: Address,
amount: Uint<256, 4>,
memo: FixedBytes<32>,
) -> ITIP20Events
pub fn transfer_with_memo( from: Address, to: Address, amount: Uint<256, 4>, memo: FixedBytes<32>, ) -> ITIP20Events
Creates a TransferWithMemo event.
event TransferWithMemo(address,address,uint256,bytes32)pub fn transfer_policy_update(
updater: Address,
new_policy_id: u64,
) -> ITIP20Events
pub fn transfer_policy_update( updater: Address, new_policy_id: u64, ) -> ITIP20Events
Creates a TransferPolicyUpdate event.
event TransferPolicyUpdate(address,uint64)pub fn supply_cap_update(
updater: Address,
new_supply_cap: Uint<256, 4>,
) -> ITIP20Events
pub fn supply_cap_update( updater: Address, new_supply_cap: Uint<256, 4>, ) -> ITIP20Events
Creates a SupplyCapUpdate event.
event SupplyCapUpdate(address,uint256)pub fn pause_state_update(updater: Address, is_paused: bool) -> ITIP20Events
pub fn pause_state_update(updater: Address, is_paused: bool) -> ITIP20Events
Creates a PauseStateUpdate event.
event PauseStateUpdate(address,bool)pub fn next_quote_token_set(
updater: Address,
next_quote_token: Address,
) -> ITIP20Events
pub fn next_quote_token_set( updater: Address, next_quote_token: Address, ) -> ITIP20Events
Creates a NextQuoteTokenSet event.
event NextQuoteTokenSet(address,address)pub fn quote_token_update(
updater: Address,
new_quote_token: Address,
) -> ITIP20Events
pub fn quote_token_update( updater: Address, new_quote_token: Address, ) -> ITIP20Events
Creates a QuoteTokenUpdate event.
event QuoteTokenUpdate(address,address)pub fn reward_distributed(funder: Address, amount: Uint<256, 4>) -> ITIP20Events
pub fn reward_distributed(funder: Address, amount: Uint<256, 4>) -> ITIP20Events
Creates a RewardDistributed event.
event RewardDistributed(address,uint256)pub fn reward_recipient_set(holder: Address, recipient: Address) -> ITIP20Events
pub fn reward_recipient_set(holder: Address, recipient: Address) -> ITIP20Events
Creates a RewardRecipientSet event.
event RewardRecipientSet(address,address)pub fn logo_uri_updated(updater: Address, new_logo_uri: String) -> ITIP20Events
pub fn logo_uri_updated(updater: Address, new_logo_uri: String) -> ITIP20Events
Creates a LogoURIUpdated event.
event LogoURIUpdated(address,string)Trait Implementations
impl Clone for ITIP20Events
impl Clone for ITIP20Events
fn clone(&self) -> ITIP20Events
fn clone(&self) -> ITIP20Events
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for ITIP20Events
impl Debug for ITIP20Events
impl<'de> Deserialize<'de> for ITIP20Events
impl<'de> Deserialize<'de> for ITIP20Events
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ITIP20Events, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ITIP20Events, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Eq for ITIP20Events
impl IntoLogData for ITIP20Events
impl IntoLogData for ITIP20Events
fn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.fn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.impl PartialEq for ITIP20Events
impl PartialEq for ITIP20Events
impl Serialize for ITIP20Events
impl Serialize for ITIP20Events
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl SolEventInterface for ITIP20Events
impl SolEventInterface for ITIP20Events
fn decode_raw_log(
topics: &[FixedBytes<32>],
data: &[u8],
) -> Result<ITIP20Events, Error>
fn decode_raw_log( topics: &[FixedBytes<32>], data: &[u8], ) -> Result<ITIP20Events, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for ITIP20Events